@@ -11,10 +11,13 @@ g.inspectfile = function(datafile) {
     if (tmp1[length(tmp1)] == "v") { #this is a csv file
       dformat = 2 #2 = csv
       testcsv = read.csv(paste(datafile,sep=""),nrow=10,skip=10)
-      if (ncol(testcsv) == 2) { #it is a geneactivefile
+      testcsvtopline = read.csv(paste(datafile,sep=""),nrow=2,skip=1)
+      if (ncol(testcsv) == 2 & ncol(testcsvtopline) < 4) { #it is a geneactivefile
         mon = 2
-      } else if (ncol(testcsv) >= 3) {	#it is an actigraph file
+      } else if (ncol(testcsv) >= 3 & ncol(testcsvtopline) < 4) {	#it is an actigraph file
         mon = 3
+      } else if (ncol(testcsv) >= 4 & ncol(testcsvtopline) >= 4) { # it is an AX3 file
+        mon = 4
       }
     } else if (tmp2[length(tmp2)] == "in") { #this is a bin file
       dformat = 1 #1 = binary
@@ -27,6 +30,9 @@ g.inspectfile = function(datafile) {
     }
     if (dformat == 1) { # .bin
       # try read the file as if it is a geneactiv and store output in variable 'isitageneactive'
+      if("GENEAread" %in% rownames(installed.packages()) == FALSE) {
+        cat("\nWarning: R package GENEAread has not been installed, please install it before continuing")
+      }
       suppressWarnings(try(expr={isitageneactive = GENEAread::header.info(binfile=datafile)},silent=TRUE))
       # try read the file as if it is a genea and store output in variable 'isitagenea'
       try(expr={isitagenea = g.binread(datafile,0,1)},silent=TRUE)
@@ -119,6 +125,12 @@ g.inspectfile = function(datafile) {
         } else { #decimals seperated by dot
           sf = as.numeric(tmp3[1])			
         }
+      } else if (mon == 4) {
+        # sample frequency is not stored
+        tmp0 = read.csv(datafile,nrow=100000,skip=0)
+        tmp1 = as.numeric(as.POSIXlt(tmp0[,1]))
+        sf = length(tmp1) / (tmp1[length(tmp1)] - tmp1[1])
+        sf = floor((sf) /5 ) *5 # round to nearest interget of 5
       }
     } else if (dformat == 3) { # wav
       H = tuneR::readWave(datafile,from = 1, to = 10,units = c("seconds"), header = TRUE)
@@ -155,8 +167,9 @@ g.inspectfile = function(datafile) {
       H = read.csv(datafile,nrow=20,skip=0) #note that not the entire header is copied
     } else if (mon == 3) { #geneactive
       H = read.csv(datafile,nrow=9,skip=0)
+    } else if (mon == 4) { #ax3 (axivity)
+      H = "file does not have header" # these files have no header
     }
-   
   } else if (dformat == 3) { #wav data
     header = c()
     try(expr={header = rownames(read.csv(datafile,nrow=15,header=TRUE))},silent=TRUE)
@@ -234,7 +247,10 @@ g.inspectfile = function(datafile) {
     }
   }
   closeAllConnections()
-  if (dformat != 4) header = data.frame(value=H[,2],row.names=H[,1])
+
+  RowsWithData = which(is.na(H[,1]) == FALSE)
+  
+  if (dformat != 4) header = data.frame(value=H[RowsWithData,2],row.names=H[RowsWithData,1])
   monc = mon
   monn = monnames[mon]
   dformc = dformat
